/**************************************************************************
*  Copyright (c) 2016 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  28.12.2016  mifi  First Version for the Altera DE1-SoC board.
**************************************************************************/
#define __MAIN_C__

/*=======================================================================*/
/*  Includes                                                             */
/*=======================================================================*/
#include <stdint.h>

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

typedef void (*irq_fnt)(void);

/*=======================================================================*/
/*  Definition of all global Data                                        */
/*=======================================================================*/

irq_fnt interrupt_handlers[256];

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/
static const uint32_t d  = 7;
static const float    fd = 5.3f;
static uint32_t       dd = 8;

/* Must be 0, BSS must be cleared by the startup */
static uint32_t       must_zero_after_startup;

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/

/*************************************************************************/
/*  main                                                                 */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: never                                                        */
/*************************************************************************/
int main (void)
{
  uint32_t a  = 1;
  uint32_t b  = 2;
  uint32_t c  = 0;
  float    fa = 1.3f;
  float    fb = 2.7f;
  float    fc = 3.9f;
  
  fa = fa + fd;
  a  = a + d + dd + must_zero_after_startup;
  
  /* A must be 16 here */
  if (a != 16) while (1) {};
    
  while (1)
  {
    a++;
    b++;
    c = a + b;
    
    fa = fa + 2.6f;
    fb = fb + 1.67f;
    fc = fa + fb;
  }

  /*
   * Prevent compiler warnings
   */
  (void)fc;
  (void)c;   
  
  /*
   * This return here make no sense.
   * But to prevent the compiler warning:
   * "return type of 'main' is not 'int'
   * we use an int as return :-)
   */ 
  return(0);
}

/*** EOF ***/
